@@ -36,7 +36,7 @@ class Users(object):
 		self.visible_email = None
 
 		# system variables.
-		self.verification_codes = Files.Dictionary(path=None, dictionary={})
+		self.verification_codes = Files.Dictionary(path=False, dictionary={})
 
 		#
 	def get(self, 
